@@ -370,9 +370,11 @@ def validate_dims_against_main(main_shape, dims, is_spectroscopic=True):
         dim_category = 'Position'
 
     # TODO: This is where the dimension type will need to be taken into account:
-    if main_shape[main_dim] != np.product([len(x.values) for x in dims]):
-        raise ValueError(dim_category + ' dimensions in main data do not match with product of values in provided '
-                                        'Dimension objects')
+    lhs = main_shape[main_dim]
+    rhs = np.product([len(x.values) for x in dims])
+    if lhs != rhs:
+        raise ValueError(dim_category + ' dimensions in main data of size: {} do not match with product of values in provided '
+                                        'Dimension objects: {}'.format(lhs, rhs))
 
 
 def check_if_main(h5_main, verbose=False):
@@ -502,7 +504,12 @@ def link_as_main(h5_main, h5_pos_inds, h5_pos_vals, h5_spec_inds, h5_spec_vals):
     link_h5_obj_as_alias(h5_main, h5_spec_vals, 'Spectroscopic_Values')
 
     from ..usi_data import USIDataset
-    return USIDataset(h5_main)
+    try:
+        # If all other conditions are satisfied
+        return USIDataset(h5_main)
+    except TypeError:
+        # If some other conditions are yet to be satisfied
+        return h5_main
 
 
 def check_for_old(h5_base, tool_name, new_parms=None, target_dset=None, verbose=False):
