@@ -16,8 +16,7 @@ import shutil
 sys.path.append("../../pyUSID/")
 from pyUSID.io import hdf_utils, write_utils, USIDataset
 
-from tests.io import data_utils
-
+from tests.processing import data_utils
 
 if sys.version_info.major == 3:
     unicode = str
@@ -32,7 +31,7 @@ class TestModel(unittest.TestCase):
         data_utils.make_relaxation_file()
 
     def tearDown(self):
-        for file_path in [data_utils.std_beps_path, 
+        for file_path in [data_utils.std_beps_path,
                           data_utils.sparse_sampling_path,
                           data_utils.incomplete_measurement_path,
                           data_utils.relaxation_path]:
@@ -525,10 +524,10 @@ class TestWriteMainDataset(TestModel):
             self.assertTrue(np.allclose(main_data, usid_main[()]))
 
             data_utils.validate_aux_dset_pair(self, h5_f, usid_main.h5_pos_inds, usid_main.h5_pos_vals, pos_names, pos_units,
-                                          pos_data, h5_main=usid_main, is_spectral=False)
+                                              pos_data, h5_main=usid_main, is_spectral=False)
 
             data_utils.validate_aux_dset_pair(self, h5_f, usid_main.h5_spec_inds, usid_main.h5_spec_vals, spec_names, spec_units,
-                                          spec_data, h5_main=usid_main, is_spectral=True)
+                                              spec_data, h5_main=usid_main, is_spectral=True)
         os.remove(file_path)
 
     def test_dask(self):
@@ -568,10 +567,10 @@ class TestWriteMainDataset(TestModel):
             self.assertTrue(np.allclose(main_data, usid_main[()]))
 
             data_utils.validate_aux_dset_pair(self, h5_f, usid_main.h5_pos_inds, usid_main.h5_pos_vals, pos_names, pos_units,
-                                          pos_data, h5_main=usid_main, is_spectral=False)
+                                              pos_data, h5_main=usid_main, is_spectral=False)
 
             data_utils.validate_aux_dset_pair(self, h5_f, usid_main.h5_spec_inds, usid_main.h5_spec_vals, spec_names, spec_units,
-                                          spec_data, h5_main=usid_main, is_spectral=True)
+                                              spec_data, h5_main=usid_main, is_spectral=True)
         os.remove(file_path)
 
     def test_empty(self):
@@ -610,10 +609,10 @@ class TestWriteMainDataset(TestModel):
             self.assertEqual(main_data, usid_main.shape)
 
             data_utils.validate_aux_dset_pair(self, h5_f, usid_main.h5_pos_inds, usid_main.h5_pos_vals, pos_names, pos_units,
-                                          pos_data, h5_main=usid_main, is_spectral=False)
+                                              pos_data, h5_main=usid_main, is_spectral=False)
 
             data_utils.validate_aux_dset_pair(self, h5_f, usid_main.h5_spec_inds, usid_main.h5_spec_vals, spec_names, spec_units,
-                                          spec_data, h5_main=usid_main, is_spectral=True)
+                                              spec_data, h5_main=usid_main, is_spectral=True)
         os.remove(file_path)
 
     def test_write_main_existing_spec_aux(self):
@@ -644,15 +643,15 @@ class TestWriteMainDataset(TestModel):
 
         with h5py.File(file_path) as h5_f:
             h5_spec_inds, h5_spec_vals = hdf_utils.write_ind_val_dsets(h5_f, spec_dims, is_spectral=True)
-            data_utils.validate_aux_dset_pair(self,h5_f, h5_spec_inds, h5_spec_vals, spec_names, spec_units, spec_data,
-                                          is_spectral=True)
+            data_utils.validate_aux_dset_pair(self, h5_f, h5_spec_inds, h5_spec_vals, spec_names, spec_units, spec_data,
+                                              is_spectral=True)
 
             usid_main = hdf_utils.write_main_dataset(h5_f, main_data, main_data_name, quantity, dset_units, pos_dims,
                                                       None, h5_spec_inds=h5_spec_inds, h5_spec_vals=h5_spec_vals,
                                                       main_dset_attrs=None)
 
-            data_utils.validate_aux_dset_pair(self,h5_f, usid_main.h5_pos_inds, usid_main.h5_pos_vals, pos_names, pos_units,
-                                          pos_data, h5_main=usid_main, is_spectral=False)
+            data_utils.validate_aux_dset_pair(self, h5_f, usid_main.h5_pos_inds, usid_main.h5_pos_vals, pos_names, pos_units,
+                                              pos_data, h5_main=usid_main, is_spectral=False)
 
         os.remove(file_path)
 
@@ -691,11 +690,11 @@ class TestWriteMainDataset(TestModel):
                                                       h5_pos_vals=h5_pos_vals, h5_pos_inds=h5_pos_inds,
                                                       main_dset_attrs=None)
 
-            data_utils.validate_aux_dset_pair(self,h5_f, h5_pos_inds, h5_pos_vals, pos_names, pos_units,
-                                          pos_data, h5_main=usid_main, is_spectral=False)
+            data_utils.validate_aux_dset_pair(self, h5_f, h5_pos_inds, h5_pos_vals, pos_names, pos_units,
+                                              pos_data, h5_main=usid_main, is_spectral=False)
 
-            data_utils.validate_aux_dset_pair(self,h5_f, h5_spec_inds, h5_spec_vals, spec_names,spec_units,
-                                          spec_data, h5_main=usid_main, is_spectral=True)
+            data_utils.validate_aux_dset_pair(self, h5_f, h5_spec_inds, h5_spec_vals, spec_names, spec_units,
+                                              spec_data, h5_main=usid_main, is_spectral=True)
         os.remove(file_path)
 
     def test_prod_sizes_mismatch(self):
