@@ -15,8 +15,7 @@ import shutil
 sys.path.append("../../pyUSID/")
 from pyUSID.io import hdf_utils, write_utils, USIDataset
 
-from tests.io import data_utils
-
+from tests.processing import data_utils
 
 if sys.version_info.major == 3:
     unicode = str
@@ -189,7 +188,7 @@ class TestWriteIndValDsets(TestSimple):
         with h5py.File(file_path, mode='w') as h5_f:
             h5_inds, h5_vals = hdf_utils.write_ind_val_dsets(h5_f, descriptor, is_spectral=False)
 
-            data_utils.validate_aux_dset_pair(self,h5_f, h5_inds, h5_vals, dim_names, dim_units, pos_data,
+            data_utils.validate_aux_dset_pair(self, h5_f, h5_inds, h5_vals, dim_names, dim_units, pos_data,
                                               is_spectral=False)
 
         os.remove(file_path)
@@ -214,7 +213,7 @@ class TestWriteIndValDsets(TestSimple):
             h5_inds, h5_vals = hdf_utils.write_ind_val_dsets(h5_group, descriptor, is_spectral=True)
 
             data_utils.validate_aux_dset_pair(self, h5_group, h5_inds, h5_vals, dim_names, dim_units, spec_data,
-                                          is_spectral=True)
+                                              is_spectral=True)
         os.remove(file_path)
 
     def test_legal_override_steps_offsets_base_name(self):
@@ -245,7 +244,7 @@ class TestWriteIndValDsets(TestSimple):
             h5_inds, h5_vals = hdf_utils.write_ind_val_dsets(h5_group, descriptor, is_spectral=True,
                                                              base_name=new_base_name)
             data_utils.validate_aux_dset_pair(self, h5_group, h5_inds, h5_vals, dim_names, dim_units, spec_inds,
-                                          vals_matrix=spec_vals, base_name=new_base_name, is_spectral=True)
+                                              vals_matrix=spec_vals, base_name=new_base_name, is_spectral=True)
         os.remove(file_path)
 
     def test_illegal(self):
@@ -733,13 +732,13 @@ class TestCreateIndexedGroup(TestSimple):
             self.assertIsInstance(h5_group, h5py.Group)
             self.assertEqual(h5_group.name, '/Hello_000')
             self.assertEqual(h5_group.parent, h5_f)
-            data_utils.verify_book_keeping_attrs(self,  h5_group)
+            data_utils.verify_book_keeping_attrs(self, h5_group)
 
             h5_sub_group = hdf_utils.create_indexed_group(h5_group, 'Test')
             self.assertIsInstance(h5_sub_group, h5py.Group)
             self.assertEqual(h5_sub_group.name, '/Hello_000/Test_000')
             self.assertEqual(h5_sub_group.parent, h5_group)
-            data_utils.verify_book_keeping_attrs(self,  h5_sub_group)
+            data_utils.verify_book_keeping_attrs(self, h5_sub_group)
         os.remove(file_path)
 
     def test_second(self):
@@ -750,13 +749,13 @@ class TestCreateIndexedGroup(TestSimple):
             self.assertIsInstance(h5_group_1, h5py.Group)
             self.assertEqual(h5_group_1.name, '/Hello_000')
             self.assertEqual(h5_group_1.parent, h5_f)
-            data_utils.verify_book_keeping_attrs(self,  h5_group_1)
+            data_utils.verify_book_keeping_attrs(self, h5_group_1)
 
             h5_group_2 = hdf_utils.create_indexed_group(h5_f, 'Hello')
             self.assertIsInstance(h5_group_2, h5py.Group)
             self.assertEqual(h5_group_2.name, '/Hello_001')
             self.assertEqual(h5_group_2.parent, h5_f)
-            data_utils.verify_book_keeping_attrs(self,  h5_group_2)
+            data_utils.verify_book_keeping_attrs(self, h5_group_2)
         os.remove(file_path)
 
     def test_w_suffix_(self):
@@ -767,7 +766,7 @@ class TestCreateIndexedGroup(TestSimple):
             self.assertIsInstance(h5_group, h5py.Group)
             self.assertEqual(h5_group.name, '/Hello_000')
             self.assertEqual(h5_group.parent, h5_f)
-            data_utils.verify_book_keeping_attrs(self,  h5_group)
+            data_utils.verify_book_keeping_attrs(self, h5_group)
         os.remove(file_path)
 
     def test_empty_base_name(self):
@@ -812,14 +811,14 @@ class TestCreateResultsGroup(TestSimple):
             self.assertIsInstance(h5_group, h5py.Group)
             self.assertEqual(h5_group.name, '/Main-' + tool_name + '_000')
             self.assertEqual(h5_group.parent, h5_f)
-            data_utils.verify_book_keeping_attrs(self,  h5_group)
+            data_utils.verify_book_keeping_attrs(self, h5_group)
 
             h5_dset = h5_group.create_dataset('Main_Dataset', data=[1, 2, 3])
             h5_sub_group = hdf_utils.create_results_group(h5_dset, 'SHO_Fit')
             self.assertIsInstance(h5_sub_group, h5py.Group)
             self.assertEqual(h5_sub_group.name, '/Main-' + tool_name + '_000/Main_Dataset-SHO_Fit_000')
             self.assertEqual(h5_sub_group.parent, h5_group)
-            data_utils.verify_book_keeping_attrs(self,  h5_sub_group)
+            data_utils.verify_book_keeping_attrs(self, h5_sub_group)
         os.remove(file_path)
 
     def test_second(self):
@@ -831,13 +830,13 @@ class TestCreateResultsGroup(TestSimple):
             self.assertIsInstance(h5_group, h5py.Group)
             self.assertEqual(h5_group.name, '/Main-Tool_000')
             self.assertEqual(h5_group.parent, h5_f)
-            data_utils.verify_book_keeping_attrs(self,  h5_group)
+            data_utils.verify_book_keeping_attrs(self, h5_group)
 
             h5_sub_group = hdf_utils.create_results_group(h5_dset, 'Tool')
             self.assertIsInstance(h5_sub_group, h5py.Group)
             self.assertEqual(h5_sub_group.name, '/Main-Tool_001')
             self.assertEqual(h5_sub_group.parent, h5_f)
-            data_utils.verify_book_keeping_attrs(self,  h5_sub_group)
+            data_utils.verify_book_keeping_attrs(self, h5_sub_group)
         os.remove(file_path)
 
     def test_empty_tool_name(self):
@@ -886,7 +885,7 @@ class TestAssignGroupIndex(TestSimple):
                 _ = hdf_utils.assign_group_index(h5_group, 1.24)
 
 
-class TestLinkAdMain(TestSimple):
+class TestLinkAsMain(TestSimple):
 
     def test_pos_args_not_h5_dset(self):
         file_path = 'link_as_main.h5'
@@ -957,7 +956,7 @@ class TestLinkAdMain(TestSimple):
 
         data_utils.delete_existing_file(file_path)
 
-    def test_typical(self):
+    def helper_test(self, quant_units_specified):
         file_path = 'link_as_main.h5'
         data_utils.delete_existing_file(file_path)
         with h5py.File(file_path) as h5_f:
@@ -998,7 +997,12 @@ class TestLinkAdMain(TestSimple):
 
             source_main_data = np.random.rand(num_rows * num_cols, num_cycle_pts * num_cycles)
             h5_source_main = h5_raw_grp.create_dataset(source_dset_name, data=source_main_data)
-            data_utils.write_safe_attrs(h5_source_main, {'units': 'A', 'quantity': 'Current'})
+
+            expected_type = h5py.Dataset
+
+            if quant_units_specified:
+                expected_type = USIDataset
+                data_utils.write_safe_attrs(h5_source_main, {'units': 'A', 'quantity': 'Current'})
 
             self.assertFalse(hdf_utils.check_if_main(h5_source_main))
 
@@ -1007,11 +1011,19 @@ class TestLinkAdMain(TestSimple):
                                                  h5_source_spec_vals)
 
             # Finally:
-            self.assertTrue(hdf_utils.check_if_main(h5_source_main))
-            self.assertIsInstance(usid_source, USIDataset)
+            if quant_units_specified:
+                self.assertTrue(hdf_utils.check_if_main(h5_source_main))
+
+            self.assertIsInstance(usid_source, expected_type)
 
         os.remove(file_path)
 
+    def test_typical_attrs_specified(self):
+        self.helper_test(True)
+
+    def test_typical_attrs_not_specified(self):
+        self.helper_test(False)
+
 
 class TestCopyAttributes(TestSimple):
 
