@@ -10,14 +10,25 @@ import sys
 
 sys.path.append("../../pyUSID/")
 from pyUSID.io import io_utils
+from pyUSID.processing import comp_utils
 
 
-class TestIOUtils(unittest.TestCase):
+class TestFormattedStrToNum(unittest.TestCase):
 
-    def test_formatted_str_to_number(self):
+    def test_typical(self):
         self.assertEqual(io_utils.formatted_str_to_number("4.32 MHz", ["MHz", "kHz"], [1E+6, 1E+3]), 4.32E+6)
 
-    def test_formatted_str_to_number_invalid(self):
+    def test_wrong_types(self):
+        with self.assertRaises(TypeError):
+            _ = io_utils.formatted_str_to_number({'dfdfd': 123}, ["MHz"], [1E+6])
+        with self.assertRaises(TypeError):
+            _ = io_utils.formatted_str_to_number("dfdfdf", ["MHz"], 1E+6)
+        with self.assertRaises(TypeError):
+            _ = io_utils.formatted_str_to_number("jkjk", ["MHz", 1234], [1E+6, 1E+4])
+        with self.assertRaises(TypeError):
+            _ = io_utils.formatted_str_to_number("4.32 MHz", ["MHz", "kHz"], [{'dfdfd': 13}, 1E+3])
+
+    def test_invalid(self):
         with self.assertRaises(ValueError):
             _ = io_utils.formatted_str_to_number("4.32 MHz", ["MHz"], [1E+6, 1E+3])
         with self.assertRaises(ValueError):
@@ -31,7 +42,10 @@ class TestIOUtils(unittest.TestCase):
         with self.assertRaises(ValueError):
             _ = io_utils.formatted_str_to_number("MHz", ["MHz", "kHz"], [1E+6, 1E+3])
 
-    def test_format_quantity(self):
+
+class TestFormatQuantity(unittest.TestCase):
+
+    def test_typical(self):
         qty_names = ['sec', 'mins', 'hours', 'days']
         qty_factors = [1, 60, 3600, 3600*24]
         ret_val = io_utils.format_quantity(315, qty_names, qty_factors)
@@ -39,7 +53,7 @@ class TestIOUtils(unittest.TestCase):
         ret_val = io_utils.format_quantity(6300, qty_names, qty_factors)
         self.assertEqual(ret_val, '1.75 hours')
 
-    def test_format_quantity_illegal(self):
+    def test_illegal(self):
         with self.assertRaises(ValueError):
             _ = io_utils.format_quantity(315, ['sec', 'mins', 'hours'], [1, 60, 3600, 3600*24])
         with self.assertRaises(ValueError):
@@ -49,6 +63,9 @@ class TestIOUtils(unittest.TestCase):
         with self.assertRaises(TypeError):
             _ = io_utils.format_quantity('hello', ['sec', 'mins', 'hours'], [1, 60, 3600])
 
+
+class TestTimeSizeFormatting(unittest.TestCase):
+
     def test_format_time(self):
         ret_val = io_utils.format_time(315)
         self.assertEqual(ret_val, '5.25 mins')
@@ -62,5 +79,20 @@ class TestIOUtils(unittest.TestCase):
         self.assertEqual(ret_val, '5.43 GB')
 
 
+class TestIOUtils(unittest.TestCase):
+
+    def test_get_available_memory_rerouting(self):
+        if sys.version_info.major == 3:
+            with self.assertWarns(FutureWarning):
+                _ = io_utils.get_available_memory()
+        self.assertEqual(comp_utils.get_available_memory(), io_utils.get_available_memory())
+
+    def test_recommend_cpu_cores_rerouting(self):
+        if sys.version_info.major == 3:
+            with self.assertWarns(FutureWarning):
+                _ = io_utils.recommend_cpu_cores(140)
+        self.assertEqual(comp_utils.recommend_cpu_cores(140), io_utils.recommend_cpu_cores(140))
+
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
