@@ -11,7 +11,8 @@ import sys
 import h5py
 import numpy as np
 
-from . import data_utils
+from tests.processing import data_utils
+
 sys.path.append("../../pyUSID/")
 from pyUSID.io.hdf_utils import get_attr
 from pyUSID.io import reg_ref
@@ -327,4 +328,4 @@ class TestRegRef(unittest.TestCase):
             dim_names = ['Bias']
             ret_val = reg_ref.attempt_reg_ref_build(h5_dset, dim_names)
             self.assertEqual(ret_val, dict())
-        os.remove(file_path)
\ No newline at end of file
+        os.remove(file_path)
